# Shodo Python

The Shodo Python help you, lint Japanese text and download posts and images.

## Installation

Normal installation provides only Shodo Python CLI. To use the Shodo Python CLI.  
Install Shodo Python CLI using pip:

```bash
$ pip install shodo
```

Or, to include the optional asyncio support for programming, use:

```bash
$ pip install shodo[async]
```

## Usage

Installing the CLI provides access to the `shodo` command.

```bash
$ shodo [COMMAND]

# Run `--help` for more information about CLI commands
$ shodo [COMMAND] --help
```

## Commands

The Shodo Python CLI provides the following commands:

* [`login`](https://developer.shodo.ink/docs/shodo-cli-reference#shodo-login)
* [`lint`](https://developer.shodo.ink/docs/shodo-cli-reference#shodo-lint)
* [`download`](https://developer.shodo.ink/docs/shodo-cli-reference#shodo-download)

## Documentation

For additional information, please refer to the [Shodo Python CLI documentation](https://developer.shodo.ink/docs/shodo-cli-reference).
